Model IP and Usage
=======================
If you are interested in using these models commercially this table can help you determine what you can do.

.. csv-table::
   :file: generated/model_usage.csv
   :header-rows: 1

